@@ -10,12 +10,12 @@ class DotView(object):
     def render(self, t):
         buf = ['digraph {']
 
-        for s in map(lambda x: x['name'], self._api.sources(t)['sources']):
+        for s in [x['name'] for x in self._api.sources(t)['sources']]:
             outputs = self._api.source(t, s)['source']['status']['output_stats']['outputs']
             for out in outputs.keys():
                 buf += ['{0} -> {1}'.format(s, out)]
 
-        for s in map(lambda x: x['name'], self._api.streams(t)['streams']):
+        for s in [x['name'] for x in self._api.streams(t)['streams']]:
             outputs = self._api.stream(t, s)['stream']['status']['output_stats']['outputs']
             for out in outputs.keys():
                 buf += ['{0} -> {1}'.format(s, out)]
